==> haskell-crypto-token-0.1.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.1.1
visibility:           public
id:                   crypto-token-0.1.1-E4o94r8pcYhI6V2Zw1u53v
key:                  crypto-token-0.1.1-E4o94r8pcYhI6V2Zw1u53v
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  f93d0a88f8c404d77095ffcabbe49fe3
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.1.1-E4o94r8pcYhI6V2Zw1u53v
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    crypton-1.0.2-LneO5TY4WJpHWl904fsHIO
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-token-0.1.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.1.1
visibility:           public
id:                   crypto-token-0.1.1-3ay3rWa72zCEtinQwGg6sq
key:                  crypto-token-0.1.1-3ay3rWa72zCEtinQwGg6sq
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  b59d4e0e7773a9a5070489e0b7a6732e
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.1.1-3ay3rWa72zCEtinQwGg6sq
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    crypton-1.0.2-Ehe8sflngVC8befumTC8Y7
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
